==> xl-commons-3.0.0-20171013.034325-8-sources.jar: com/xunlei/channel/common/utils/reflect/HttpReflectionUtils.java <==
package com.xunlei.channel.common.utils.reflect;

import com.xunlei.channel.common.utils.string.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

/**
 * @author xiongyingqi
 * @since 20170922//
 */
public abstract class HttpReflectionUtils {
    private static final Logger logger = LoggerFactory.getLogger(HttpReflectionUtils.class);

    public static final String PAIRS_DELIMITER = "&";
    public static final String KV_DELIMITER = "=";


    public static Map<String, String> parseHttpResponseToMap(String response) {
        if (StringUtils.isEmpty(response)) {
            return null;
        }
        HashMap<String, String> params = new HashMap<String, String>();
        String[] pairs = StringUtils.delimitedListToStringArray(response, PAIRS_DELIMITER);
        for (String pair : pairs) {
//            String[] kv = StringUtils.delimitedListToStringArray(pair, KV_DELIMITER);
//            if (kv.length != 2) {
//                logger.warn("Pair: {} is illegal!", pair);
//                continue;
//            }
//            String key = kv[0];
//            String value = kv[1];
            int i = pair.indexOf(KV_DELIMITER);
            if (i < 0) {
                logger.warn("Pair: {} is illegal!", pair);
                continue;
            }
            String key = pair.substring(0, i);
            String value = pair.substring(i + 1, pair.length());
            if (logger.isDebugEnabled()) {
                logger.debug("Parse pair to key: {} value: {}", key, value);
            }
            params.put(key, value);
        }
        return params;
    }

    public static <T> T parseHttpResponseToInstance(String response, Class<T> tClass) throws IllegalAccessException, InstantiationException {
        if (StringUtils.isEmpty(response)) {
            return null;
        }
        Map<String, String> params = parseHttpResponseToMap(response);
        T t = tClass.newInstance();
        Field[] fields = ReflectionUtils.findFields(tClass, true);
        for (Map.Entry<String, String> entry : params.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            try {
                ReflectionUtils.setFieldValueToInstance(key, value, t, fields);
            } catch (IllegalAccessException e) {
                logger.error("Error when set param: " + key + " value: " + value + " to: " + tClass + ". Error message: " + e.getMessage(), e);
            }
        }
        return t;
    }
}

==> xl-commons-3.0.0-20180301.082528-26-sources.jar: com/xunlei/channel/common/utils/reflect/HttpReflectionUtils.java <==
package com.xunlei.channel.common.utils.reflect;

import com.xunlei.channel.common.utils.CollectionUtils;
import com.xunlei.channel.common.utils.string.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

/**
 * @author xiongyingqi
 * @since 20170922//
 */
public abstract class HttpReflectionUtils {
    private static final Logger logger = LoggerFactory.getLogger(HttpReflectionUtils.class);

    public static final String PAIRS_DELIMITER = "&";
    public static final String KV_DELIMITER = "=";


    public static Map<String, String> parseHttpResponseToMap(String response) {
        if (StringUtils.isEmpty(response)) {
            return null;
        }
        HashMap<String, String> params = new HashMap<String, String>();
        String[] pairs = StringUtils.delimitedListToStringArray(response, PAIRS_DELIMITER);
        for (String pair : pairs) {
//            String[] kv = StringUtils.delimitedListToStringArray(pair, KV_DELIMITER);
//            if (kv.length != 2) {
//                logger.warn("Pair: {} is illegal!", pair);
//                continue;
//            }
//            String key = kv[0];
//            String value = kv[1];
            int i = pair.indexOf(KV_DELIMITER);
            if (i < 0) {
                logger.warn("Pair: {} is illegal!", pair);
                continue;
            }
            String key = pair.substring(0, i);
            String value = pair.substring(i + 1, pair.length());
            if (logger.isDebugEnabled()) {
                logger.debug("Parse pair to key: {} value: {}", key, value);
            }
            params.put(key, value);
        }
        return params;
    }

    public static <T> T parseHttpResponseToInstance(String response, Class<T> tClass) throws IllegalAccessException, InstantiationException {
        if (StringUtils.isEmpty(response)) {
            return null;
        }
        Map<String, String> params = parseHttpResponseToMap(response);
        return parseParamsToInstance(params, tClass);
    }

    public static <T> T parseParamsToInstance(Map<String, String> params, Class<T> tClass) throws IllegalAccessException, InstantiationException {
        if (CollectionUtils.isEmpty(params)) {
            return null;
        }
        T t = tClass.newInstance();
        Field[] fields = ReflectionUtils.findFields(tClass, true);
        for (Map.Entry<String, String> entry : params.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            try {
                ReflectionUtils.setFieldValueToInstance(key, value, t, fields);
            } catch (IllegalAccessException e) {
                logger.error("Error when set param: " + key + " value: " + value + " to: " + tClass + ". Error message: " + e.getMessage(), e);
            }
        }
        return t;
    }
}
